Package: MVar.pt
Type: Package
Language: pt-BR
Title: Analise multivariada (brazilian portuguese)
Version: 2.2.9
Date: 2026-05-07
Imports: graphics, grDevices, MASS, stats
Authors@R: c(
           person(given = c("Paulo Cesar"), family = "Ossani", 
             email = "ossanipc@hotmail.com", 
             role = c("aut", "cre"), 
             comment = c(ORCID = "0000-0002-6617-8085")), 
           person(given = c("Marcelo Angelo"), family = "Cirillo", 
             email = "macufla@gmail.com", 
             role = c("aut"), 
             comment = c(ORCID = "0000-0002-2647-439X")))
Description: Analise multivariada, tendo funcoes que executam analise de correspondencia simples (CA) e multipla (MCA), analise de componentes principais (PCA), analise de correlacao canonica (CCA), analise fatorial (FA), escalonamento multidimensional (MDS), analise discriminante linear (LDA) e quadratica (QDA), analise de cluster hierarquico e nao hierarquico, regressao linear simples e multipla, analise de multiplos fatores (MFA) para dados quantitativos, qualitativos, de frequencia (MFACT) e dados mistos, biplot, scatter plot, projection pursuit (PP), grant tour e outras funcoes uteis para a analise multivariada.
License: GPL-3
Encoding: UTF-8
LazyData: true
NeedsCompilation: yes
Author: Paulo Cesar Ossani [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6617-8085>),
  Marcelo Angelo Cirillo [aut] (ORCID:
    <https://orcid.org/0000-0002-2647-439X>)
Maintainer: Paulo Cesar Ossani <ossanipc@hotmail.com>
Repository: CRAN
Packaged: 2026-05-07 12:47:48 UTC; sec-l
Date/Publication: 2026-05-07 14:00:57 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-07 16:27:59 UTC; unix
Archs: MVar.pt.so.dSYM
